.. only:: latex

   Intro
   =====

.. include:: readme.rst

.. only:: not latex

    Contents:

.. toctree::
   :maxdepth: 1

   changelog
   upgrade

.. toctree::
   :caption: The Basics
   :maxdepth: 2

   installing
   basics
   classes
   compiling

.. toctree::
   :caption: Advanced Topics
   :maxdepth: 2

   advanced/functions
   advanced/classes
   advanced/exceptions
   advanced/smart_ptrs
   advanced/cast/index
   advanced/pycpp/index
   advanced/embedding
   advanced/misc

.. toctree::
   :caption: Extra Information
   :maxdepth: 1

   faq
   benchmark
   limitations
   reference
   cmake/index
